require 'simple_sync/simple_sync'
require 'test_helper'
require 'pry'

class SimpleSyncTest < MiniTest::Test
  include MiniTest::Assertions

  MiniTest.after_run { 
    FileUtils.rm_rf(Dir.glob('test/test_destination/*'))
  }

    describe 'configuration' do
    it 'locates the configuration file' do
      sync = SimpleSync.new('test/ssh_configuration.json')
      assert_respond_to(sync, :read_config_from_file)
      config = sync.read_config_from_file
      assert_equal('success', config[:status])
    end

    it 'loads configuration file' do
      sync = SimpleSync.new('test/ssh_configuration.json')
      assert_respond_to(sync, :load_config)
      assert_equal({ status: 'success' }, sync.load_config)
      configurations = sync.config_list
      assert_equal("-azrv --recursive -e ssh -i /Users/someuser/.ssh/backup_server", configurations[:configurations][0][:config][:rsync])
      assert_equal("ssh configuration", configurations[:configurations][0][:config][:name])

      sync = SimpleSync.new('test/multiple_configurations.json')
      assert_respond_to(sync, :load_config)
      assert_equal({ status: 'success' }, sync.load_config)
      configurations = sync.config_list

      assert_equal("1st configuration", configurations[:configurations][0][:config][:name])
      assert_equal("-azv", configurations[:configurations][0][:config][:rsync])
      #assert_equal("2>&1", configurations[:configurations][0][:config][:rsync_suffix])

      assert_equal("2nd configuration", configurations[:configurations][1][:config][:name])
      assert_equal("-azrv", configurations[:configurations][1][:config][:rsync])
    end

    it 'copies source files/directories  to destination directories' do
      sync = SimpleSync.new('test/multiple_configurations.json')
      assert_respond_to(sync, :copy_to_destination)
      sync.load_config
      sync.copy_to_destination
      assert File.exists?('test/test_destination/first_config/file1.txt'), "file1.txt didn't exist"
      assert File.exists?('test/test_destination/first_config/file2.txt'), "file2.txt didn't exist"
      assert File.exists?('test/test_destination/second_config/somedirectory/dir1/another_file1.txt'), "another_file1.txt didn't exist"
      assert File.exists?('test/test_destination/second_config/somedirectory/dir2/another_file2.txt'), "another_file1.txt didn't exist"
    end
  end
end
